Class: Groove::Fingerprinter::GrooveFingerprinter

Inherits:
FFI::Struct
  • Object
show all
Defined in:
lib/groove/fingerprinter.rb

Overview

(Not documented)

Fields:

:info_queue_size ::

(Integer) maximum number of GrooveFingerprinterInfo items to store in this
fingerprinter's queue. this defaults to MAX_INT, meaning that
the fingerprinter will cause the decoder to decode the entire
playlist. if you want to instead, for example, obtain fingerprints
at the same time as playback, you might set this value to 1.

:sink_buffer_size ::

(Integer) how big the sink buffer should be, in sample frames.
groove_fingerprinter_create defaults this to 8192

:playlist ::

(FFI::Pointer(*GroovePlaylist)) read-only. set when attached and cleared when detached