Class: Groove::GrooveBuffer

Inherits:
FFI::Struct
  • Object
show all
Defined in:
lib/groove/groove.rb

Overview

GrooveBuffer

Fields:

:data ::

(FFI::Pointer(**Uint8T)) all fields read-only
for interleaved audio, data(0) is the buffer.
for planar audio, each channel has a separate data pointer.
for encoded audio, data(0) is the encoded buffer.

:format ::

(GrooveAudioFormat) 

:frame_count ::

(Integer) number of audio frames described by this buffer
for encoded audio, this is unknown and set to 0.

:item ::

(GroovePlaylistItem) when encoding, if item is NULL, this is a format header or trailer.
otherwise, this is encoded audio for the item specified.
when decoding, item is never NULL.

:pos ::

(Float) 

:size ::

(Integer) total number of bytes contained in this buffer

:pts ::

(Integer) presentation time stamp of the buffer