Class: Groove::Loudness::GrooveLoudnessDetectorInfo

Inherits:
FFI::Struct
  • Object
show all
Defined in:
lib/groove/loudness.rb

Overview

(Not documented)

Fields:

:loudness ::

(Float) loudness is in LUFS. 1 LUFS == 1 dB
EBU R128 specifies that playback should target -23 LUFS. replaygain on
the other hand is a suggestion of how many dB to adjust the gain so
that it equals -18 dB.
so, for playback you might adjust the gain so that it is equal to -18 dB
(this would be the replaygain standard) or so that it is equal to -23 dB
(this would be the EBU R128 standard).

:peak ::

(Float) peak amplitude in float format

:duration ::

(Float) how many seconds long this song is

:item ::

(FFI::Pointer(*GroovePlaylistItem)) if item is NULL, this info applies to all songs analyzed until
this point. otherwise it is the playlist item that this info
applies to.
when disable_album is set, this sentinel is still sent, but loudness
will be set to 0